# Extract Audio Files From URLs

In this guide you will learn how to extract audio files from URLs.

## Why extract audio files from URLs?
Sometimes you need a sample for your collection that cannot be obtained any other way than by extracting the audio embedded in a webpage.

This feature is a simple wrapper around the `youtube-dl` package.

## How it's done

1. Run the command `djtools --url-download <URL> --url-download-destination <PATH>`
